@@ -6,9 +6,13 @@
 import logging
 from typing import Iterator, List, Optional
 
+from tenacity import retry, stop_after_delay, wait_random_exponential
+
 from asconnect.httpclient import HttpClient
 from asconnect.models import (
     AppStoreVersion,
+    AppStoreVersionPhasedRelease,
+    PhasedReleaseState,
     Platform,
     AppStoreVersionLocalization,
     AppStoreReviewDetails,
@@ -23,7 +27,12 @@ class VersionClient:
     log: logging.Logger
     http_client: HttpClient
 
-    def __init__(self, *, http_client: HttpClient, log: logging.Logger,) -> None:
+    def __init__(
+        self,
+        *,
+        http_client: HttpClient,
+        log: logging.Logger,
+    ) -> None:
         """Construct a new client object.
 
         :param http_client: The API HTTP client
@@ -33,7 +42,11 @@ class VersionClient:
         self.http_client = http_client
         self.log = log.getChild("version")
 
-    def get(self, *, version_id: str,) -> Optional[AppStoreVersion]:
+    def get(
+        self,
+        *,
+        version_id: str,
+    ) -> Optional[AppStoreVersion]:
         """Get the version with the given ID
 
         :param version_id: The version ID to get
@@ -83,7 +96,90 @@ class VersionClient:
         """
         return next_or_none(self.get_all(app_id=app_id, version_string=version_string))
 
-    def get_localizations(self, *, version_id: str,) -> Iterator[AppStoreVersionLocalization]:
+    def get_phased_release(
+        self,
+        *,
+        version_id: str,
+    ) -> Optional[AppStoreVersionPhasedRelease]:
+        """Get the phased release of given app version
+
+        :param version_id: The version ID to query for phased releases
+
+        :returns: An AppStoreVersionPhasedRelease if found, None otherwise
+        """
+        url = self.http_client.generate_url(
+            f"appStoreVersions/{version_id}/appStoreVersionPhasedRelease"
+        )
+
+        return next_or_none(self.http_client.get(url=url, data_type=AppStoreVersionPhasedRelease))
+
+    def create_phased_release(
+        self,
+        *,
+        version_id: str,
+        phased_release_state: PhasedReleaseState = PhasedReleaseState.INACTIVE,
+    ) -> Optional[AppStoreVersionPhasedRelease]:
+        """Create a phased release for a given app version, defaulting to creating an inactive release.
+
+        :param version_id: The version ID to query for phased releases
+        :param phased_release_state: the state of the initial rollout
+
+        :returns: An AppStoreVersionPhasedRelease if found, None otherwise
+        """
+        return self.http_client.post(
+            endpoint="appStoreVersionPhasedReleases",
+            data={
+                "data": {
+                    "attributes": {"phasedReleaseState": phased_release_state.value},
+                    "type": "appStoreVersionPhasedReleases",
+                    "relationships": {
+                        "appStoreVersion": {"data": {"id": version_id, "type": "appStoreVersions"}}
+                    },
+                }
+            },
+            data_type=AppStoreVersionPhasedRelease,
+        )
+
+    def delete_phased_release(
+        self,
+        *,
+        phased_release_id: str,
+    ) -> None:
+        """Delete a Phased Release
+
+        :param phased_release_id: The ID of the release set to delete
+
+        :raises AppStoreConnectError: On failure to delete"""
+
+        self.http_client.delete(url=f"appStoreVersionPhasedReleases/{phased_release_id}")
+
+    def patch_phased_release(
+        self,
+        *,
+        phased_release_id: str,
+        phased_release_state: PhasedReleaseState = PhasedReleaseState.INACTIVE,
+    ) -> Optional[AppStoreVersionPhasedRelease]:
+        """Update a Phased Release
+
+        :param phased_release_id: The ID of the release set to modify
+        :param phased_release_state: The state of the phased release to transition to
+
+        :returns: The modified AppStoreVersionPhasedRelease
+
+        """
+        return self.http_client.patch(
+            endpoint=f"appStoreVersionPhasedReleases/{phased_release_id}",
+            data={
+                "data": {
+                    "attributes": {"phasedReleaseState": phased_release_state.value},
+                    "type": "appStoreVersionPhasedReleases",
+                    "id": phased_release_id,
+                }
+            },
+            data_type=AppStoreVersionPhasedRelease,
+        )
+
+    def get_localizations(self, *, version_id: str) -> Iterator[AppStoreVersionLocalization]:
         """Get the version localizations for an app version.
 
         :param version_id: The version ID to get the localizations for
@@ -104,7 +200,12 @@ class VersionClient:
 
         self.http_client.patch(
             endpoint=f"appStoreVersions/{version_id}/relationships/build",
-            data={"data": {"type": "builds", "id": build_id,}},
+            data={
+                "data": {
+                    "type": "builds",
+                    "id": build_id,
+                }
+            },
             data_type=None,
         )
 
@@ -190,6 +291,7 @@ class VersionClient:
             data_type=AppStoreReviewDetails,
         )
 
+    @retry(wait=wait_random_exponential(max=100), stop=stop_after_delay(500))
     def get_idfa(self, *, version_id: str) -> Optional[IdfaDeclaration]:
         """Get the advertising ID declaration.
 
@@ -263,7 +365,11 @@ class VersionClient:
             data_type=IdfaDeclaration,
         )
 
-    def submit_for_review(self, *, version_id: str,) -> None:
+    def submit_for_review(
+        self,
+        *,
+        version_id: str,
+    ) -> None:
         """Submit the version for review
 
         :param version_id: The ID of the version to submit for review
